##### Load data
#name <- c("case","p1c1","p1c2","p2c1","p2c2","sys","allele","height","area")
#names(data) <- name

### Load T-matrix functions
source("mixmatrix.R")

# function for calculating H=(H1,H2) and ordering the alleles after contributor
H <- function(x){
  x$contributor <- 0
  P1C1 <- (x$p1c1==x$allele)
  P1C2 <- (x$p1c2==x$allele)
  P2C1 <- (x$p2c1==x$allele)
  P2C2 <- (x$p2c2==x$allele)
# contributor is numbered such that: single P1 < mixed < single P2
  x$contributor[(P1C1|P1C2)&!(P2C1|P2C2)] <- 1
  x$contributor[(P1C1|P1C2)& (P2C1|P2C2)] <- 2
  x$contributor[(P2C1|P2C2)&!(P1C1|P1C2)] <- 3
  x$person <- 0
  x$person[(P1C1|P1C2)&!(P2C1|P2C2)] <- 1
  x$person[(P1C1|P1C2)& (P2C1|P2C2)] <- 1
  x$person[(P2C1|P2C2)&!(P1C1|P1C2)] <- 2
  x$n <- P1C1+P1C2+P2C1+P2C2
# Remove artificial peaks such as (back)stutters, drop-ins
  x <- x[x$contributor!=0,]
# order in accordance with ordering in paper
  x <- x[order(x$case,x$sys,x$person,x$allele),] 
  xsplit <- split(x,as.character(x$case))
  Hk <- function(y,...) list(Hk=sum(y$height,...)/sum(y$n,...))
  Hfct <- function(y) {
    z <- y[y$contributor!=2,]
    Htemp <- lapply(split(z,as.numeric(z$contributor)),Hk)
    htemp <- numeric(0)
    for(i in Htemp) htemp <- c(htemp,i$Hk)
    p1 <- numeric(0)
    p2 <- numeric(0)
    sys <- character(0)
    for(s in as.character(unique(y$sys))){
      sys <- c(sys,rep(s,2))
      p1 <- c(p1,y$p1c1[as.character(y$sys)==s][1],y$p1c2[as.character(y$sys)==s][1])
      p2 <- c(p2,y$p2c1[as.character(y$sys)==s][1],y$p2c2[as.character(y$sys)==s][1])
    }
    Ttrans <- ttransform(p1,p2)
    M <- y$area
    list(case=as.character(unique(y$case)),data=y[,-(10:12)],H=htemp,Tmat=Ttrans$tmat,sys=sys,p1=p1,p2=p2,ms=Ttrans$ms,M=M)
  }
  cases <- lapply(xsplit,Hfct)
  cases
}
### computes H,Tmat,ms,profiles for data
cases <- H(data) 

### Exclude cases where drop-out occured
p <- numeric(0); for(i in 1:length(cases)){ if(nrow(cases[[i]]$data)!=sum(cases[[i]]$ms)) p <- c(p,i) }
cases <- cases[-p]
